Package: OpenLand
Title: Quantitative Analysis and Visualization of LUCC
Version: 1.0.5
Authors@R: c(
    person(given = "Reginal",
           family = "Exavier",
           role = c("aut", "cre"),
           email = "reginalexavier@rocketmail.com",
           comment = c(ORCID = "0000-0002-5237-523X")),
    person(given = "Peter",
           family = "Zeilhofer",
           role = "aut",
           email = "zeilhoferpeter@gmail.com"))
Description: Tools for the analysis of land use and cover (LUC) time series. It 
    includes support for loading spatiotemporal raster data and synthesized 
    spatial plotting. Several LUC change (LUCC) metrics in regular or irregular 
    time intervals can be extracted and visualized through one- and multistep 
    sankey and chord diagrams. A complete intensity analysis according to 
    Aldwaik and Pontius (2012) <doi:10.1016/j.landurbplan.2012.02.010> is 
    implemented, including tools for the generation of standardized multilevel 
    output graphics.
License: GPL-3
URL: https://reginalexavier.github.io/OpenLand/,
        https://github.com/reginalexavier/OpenLand
BugReports: https://github.com/reginalexavier/OpenLand/issues
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.4.0)
Imports: dplyr (>= 0.8.3), tidyr (>= 1.0.0), ggplot2 (>= 3.2.1),
        gridExtra (>= 2.3), grid, circlize (>= 0.4.8), networkD3 (>=
        0.4), raster (>= 3.0.7), methods
Collate: 'OpenLand-package.R' 'rasters_input.R' 'demolandscape.R'
        'contingencyTable.R' 'data.R' 'generalfunctions.R'
        'intensityClass.R' 'generic_method.R' 'intensityAnalysis.R'
        'plotMethods.R' 'otherplots.R'
Suggests: tmap, knitr, rmarkdown, covr, testthat, spelling
VignetteBuilder: knitr
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-10 02:08:38 UTC; tredgi
Author: Reginal Exavier [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5237-523X>),
  Peter Zeilhofer [aut]
Maintainer: Reginal Exavier <reginalexavier@rocketmail.com>
Repository: CRAN
Date/Publication: 2026-07-10 06:20:08 UTC
