# Generated by roxygen2: do not edit by hand

export(.demo_landscape)
export(acc_changes)
export(barplotLand)
export(chordDiagramLand)
export(contingencyTable)
export(intensityAnalysis)
export(netgrossplot)
export(plot)
export(sankeyLand)
export(summary_dir)
export(summary_map)
exportClasses(Category)
exportClasses(Interval)
exportClasses(Transition)
exportMethods(.input_rasters)
exportMethods(plot)
import(dplyr)
import(ggplot2)
import(methods)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,text)
importFrom(grid,gpar)
importFrom(grid,textGrob)
importFrom(gridExtra,grid.arrange)
importFrom(raster,brick)
importFrom(raster,compareRaster)
importFrom(raster,crosstab)
importFrom(raster,overlay)
importFrom(raster,raster)
importFrom(raster,stack)
importFrom(raster,unstack)
importFrom(raster,values)
